Module codes

Module codes 

Code definitions and enumerations for ULS data.

This module contains all the standardized codes used in ULS records, including radio service codes, application purposes, statuses, etc.

Enums

ApplicationPurpose
Application purpose codes.
ApplicationStatus
Application status codes.
EntityType
Entity type codes for the EN (Entity) record.
LicenseStatus
License status codes.
OperatorClass
Amateur operator class codes.
RadioService
Radio service codes as defined by the FCC. These identify the type of wireless service a license is for.
RecordType
Record type codes identifying the type of record in a DAT file.