RadioService

Enum RadioService 

pub enum RadioService {
Show 142 variants AA, AB, AC, AD, AF, AH, AI, AL, AN, AR, AS, AT, AW, BA, BB, BC, BR, BS, CA, CB, CD, CE, CF, CG, CJ, CL, CM, CN, CO, CP, CR, CT, CW, CX, CY, CZ, DV, ED, GB, GC, GE, GF, GI, GJ, GL, GM, GO, GP, GR, GS, GU, GW, GX, HA, HV, IG, IK, IQ, LD, LN, LP, LS, LV, LW, MA, MC, MD, MG, MK, MM, MR, MS, MW, NC, NN, OW, PA, PB, PC, PE, PF, PK, PL, PM, PW, QA, QD, QM, QO, QQ, QT, RP, RR, RS, SA, SB, SE, SG, SL, SP, SY, TB, TC, TI, TN, TP, TS, TT, TZ, UM, UU, VX, WA, WM, WP, WR, WS, WT, WU, WX, WY, WZ, YB, YC, YD, YE, YF, YG, YH, YI, YJ, YK, YL, YM, YO, YP, YS, YU, YW, YX, ZA, ZV,
}
Radio service codes as defined by the FCC. These identify the type of wireless service a license is for.

Variants



AA

AA - Aviation Auxiliary Group



AB

AB - Aural Microwave Booster



AC

AC - Aircraft



AD

AD - AWS-4 (2000-2020 MHz and 2180-2200 MHz)



AF

AF - Aeronautical and Fixed



AH

AH - AWS-H Block (1915-1920 MHz and 1995-2000 MHz)



AI

AI - Aural Intercity Relay



AL

AL - ALL (used for assignments/transfers across services)



AN

AN - Antenna Structure Registration



AR

AR - Aviation Radionavigation



AS

AS - Aural Studio Transmitter Link



AT

AT - AWS-3 (1695-1710, 1755-1780, 2155-2180 MHz)



AW

AW - AWS (1710-1755 MHz and 2110-2155 MHz)



BA

BA - 1390-1392 MHz Band, Market Area



BB

BB - 1392-1395 and 1432-1435 MHz Bands, Market Area



BC

BC - 1670-1675 MHz Band, Market Area



BR

BR - Broadband Radio Service



BS

BS - 900 MHz Broadband Service



CA

CA - Commercial Air-ground Radiotelephone



CB

CB - BETRS



CD

CD - Paging and Radiotelephone



CE

CE - Digital Electronic Message Service - Common Carrier



CF

CF - Common Carrier Fixed Point to Point Microwave



CG

CG - General Aviation Air-ground Radiotelephone



CJ

CJ - Commercial Aviation Air-Ground Radiotelephone (800 MHz)



CL

CL - Cellular



CM

CM - Commercial Operator



CN

CN - PCS Narrowband



CO

CO - Offshore Radiotelephone



CP

CP - Part 22 VHF/UHF Paging (excluding 931MHz)



CR

CR - Rural Radiotelephone



CT

CT - Local Television Transmission



CW

CW - PCS Broadband



CX

CX - Cellular, Auctioned



CY

CY - 1910-1915/1990-1995 MHz Bands, Market Area



CZ

CZ - Part 22 931 MHz Paging



DV

DV - Multichannel Video Distribution AND Data Service



ED

ED - Educational Broadband Service



GB

GB - Business, 806-821/851-866 MHz, Conventional



GC

GC - 929-931 MHz Band, Auctioned



GE

GE - PubSafty/SpecEmer/PubSaftyNtlPlan, 806-817/851-862MHz, Conv



GF

GF - Public Safety Ntl Plan, 821-824/866-869 MHz, Conv



GI

GI - Other Indust/Land Transp, 896-901/935-940 MHz, Conv



GJ

GJ - Business/Industrial/Land Trans, 809-824/854-869 MHz, Conv



GL

GL - 900 MHz Conventional SMR (SMR, Site-Specific)



GM

GM - 800 MHz Conventional SMR (SMR, Site-specific)



GO

GO - Other Indust/Land Transp, 806-821/851-866 MHz, Conv



GP

GP - Public Safety/Spec Emerg, 806-821/851-866 MHz, Conv



GR

GR - SMR, 896-901/935-940 MHz, Conventional



GS

GS - Private Carrier Paging, 929-930 MHz



GU

GU - Business, 896-901/935-940 MHz, Conventional



GW

GW - General Wireless Communications Service



GX

GX - SMR, 806-821/851-866 MHz, Conventional



HA

HA - Amateur



HV

HV - Vanity (Amateur)



IG

IG - Industrial/Business Pool, Conventional



IK

IK - Industrial/Business Pool - Commercial, Conventional



IQ

IQ - Intelligent Transportation Service (Public Safety)



LD

LD - Local Multipoint Distribution Service



LN

LN - 902-928 MHz Location Narrowband (Non-multilateration)



LP

LP - Broadcast Auxiliary Low Power



LS

LS - Location and Monitoring Service, Multilateration (LMS)



LV

LV - Low Power Wireless Assist Video Devices



LW

LW - 902-928 MHz Location Wideband (Grandfathered AVM)



MA

MA - Marine Auxiliary Group



MC

MC - Coastal Group



MD

MD - Multipoint Distribution Service (MDS and MMDS)



MG

MG - Microwave Industrial/Business Pool



MK

MK - Alaska Group



MM

MM - Millimeter Wave 70/80/90 GHz Service



MR

MR - Marine Radiolocation Land



MS

MS - Multiple Address Service, Auctioned



MW

MW - Microwave Public Safety Pool



NC

NC - Nationwide Commercial 5 Channel, 220 MHz



NN

NN - 3650-3700 MHz



OW

OW - FCC Ownership Disclosure Information



PA

PA - Public Safety 4940-4990 MHz Band



PB

PB - 4940-4990 MHz Public Safety, Base/Mobile



PC

PC - Public Coast Stations, Auctioned



PE

PE - Digital Electronic Message Service - Private



PF

PF - 4940-4990 MHz Public Safety, Pt-to-Pt, Pt-to-Multi-Pt



PK

PK - 3.45 GHz Service



PL

PL - 3.5 GHz Band Priority Access License



PM

PM - 3.7 GHz Service



PW

PW - Public Safety Pool, Conventional



QA

QA - 220-222 MHz Band, Auctioned



QD

QD - Non-Nationwide Data, 220 MHz



QM

QM - Non-Nationwide Public Safety/Mutual Aid, 220 MHz



QO

QO - Non-Nationwide Other, 220 MHz



QQ

QQ - Intelligent Transportation Service (Non-Public Safety)



QT

QT - Non-Nationwide 5 Channel Trunked, 220 MHz



RP

RP - Broadcast Auxiliary Remote Pickup



RR

RR - Restricted Operator



RS

RS - Land Mobile Radiolocation



SA

SA - Ship Recreational or Voluntarily Equipped



SB

SB - Ship Compulsory Equipped



SE

SE - Ship Exemption



SG

SG - Conventional Public Safety 700 MHz



SL

SL - Public Safety 700 MHz Band-State License



SP

SP - 700 MHz Public Safety Broadband Nationwide License



SY

SY - Trunked Public Safety 700 MHz



TB

TB - TV Microwave Booster



TC

TC - MSS Ancillary Terrestrial Component (ATC) Leasing



TI

TI - TV Intercity Relay



TN

TN - 39 GHz, Auctioned



TP

TP - TV Pickup



TS

TS - TV Studio Transmitter Link



TT

TT - TV Translator Relay



TZ

TZ - 24 GHz Service



UM

UM - Unlicensed Wireless Microphone Registration



UU

UU - Upper Microwave Flexible Use Service



VX

VX - Instructional Television Fixed Service



WA

WA - Microwave Aviation



WM

WM - Microwave Marine



WP

WP - 700 MHz Upper Band (Block D)



WR

WR - Microwave Radiolocation



WS

WS - Wireless Communications Service



WT

WT - 600 MHz Band



WU

WU - 700 MHz Upper Band (Block C)



WX

WX - 700 MHz Guard Band



WY

WY - 700 MHz Lower Band (Blocks A, B & E)



WZ

WZ - 700 MHz Lower Band (Blocks C, D)



YB

YB - Business, 806-821/851-866 MHz, Trunked



YC

YC - SMR, 806-821/851-866 MHz, Auctioned



YD

YD - SMR, 896-901/935-940 MHz, Auctioned



YE

YE - PubSafty/SpecEmer/PubSaftyNtlPlan, 806-817/851-862MHz, Trunked



YF

YF - Public Safety Ntl Plan, 821-824/866-869 MHz, Trunked



YG

YG - Industrial/Business Pool, Trunked



YH

YH - SMR, 806-821/851-866 MHz, Auctioned (Rebanded YC license)



YI

YI - Other Indust/Land Transp, 896-901/935-940 MHz, Trunked



YJ

YJ - Business/Industrial/Land Trans, 809-824/854-869 MHz, Trunked



YK

YK - Industrial/Business Pool - Commercial, Trunked



YL

YL - 900 MHz Trunked SMR (SMR, Site-Specific)



YM

YM - 800 MHz Trunked SMR (SMR, Site-specific)



YO

YO - Other Indust/Land Transp, 806-821/851-866 MHz, Trunked



YP

YP - Public Safety/Spec Emerg, 806-821/851-866 MHz, Trunked



YS

YS - SMR, 896-901/935-940 MHz, Trunked



YU

YU - Business, 896-901/935-940 MHz, Trunked



YW

YW - Public Safety Pool, Trunked



YX

YX - SMR, 806-821/851-866 MHz, Trunked



ZA

ZA - General Mobile Radio (GMRS)



ZV

ZV - 218-219 MHz Service

Implementations

Source

impl RadioService

pub fn as_str(&self) -> &'static str

Returns the two-character code for this radio service.

pub fn description(&self) -> &'static str

Returns a human-readable description of this radio service.

pub fn is_amateur(&self) -> bool

Returns true if this is an amateur radio service.

pub fn is_maritime(&self) -> bool

Returns true if this is a ship/maritime service.

pub fn is_aircraft(&self) -> bool

Returns true if this is an aircraft service.

pub fn to_u8(&self) -> u8

Convert to a u8 for compact database storage. The encoding is stable and matches the alphabetical order of variants.

pub fn from_u8(value: u8) -> Option<Self>

Convert from a u8 database value back to RadioService. Returns None if the value is invalid.