Code definitions and enumerations for ULS data.
This module contains all the standardized codes used in ULS records, including radio service codes, application purposes, statuses, etc.
Enums
- Application
Purpose - Application purpose codes.
- Application
Status - Application status codes.
- Entity
Type - Entity type codes for the EN (Entity) record.
- License
Status - License status codes.
- Operator
Class - Amateur operator class codes.
- Radio
Service - Radio service codes as defined by the FCC. These identify the type of wireless service a license is for.
- Record
Type - Record type codes identifying the type of record in a DAT file.